@@ -3,7 +3,7 @@ package CracTools::Const;
   $CracTools::Const::DIST = 'CracTools';
 }
 # ABSTRACT: Constants for the CracTools-core
-$CracTools::Const::VERSION = '1.2';
+$CracTools::Const::VERSION = '1.21';
 use strict;
 use warnings;
 use Exporter qw(import);
@@ -11,6 +11,10 @@ use Exporter qw(import);
 
 our $NOT_AVAILABLE = 'NA';
 
+
+our $NUCLEOTIDES = ['A', 'C', 'G', 'T' ];
+
+
 1;
 
 __END__
@@ -25,7 +29,7 @@ CracTools::Const - Constants for the CracTools-core
 
 =head1 VERSION
 
-version 1.2
+version 1.21
 
 =head1 SYNOPSIS
 
@@ -43,6 +47,8 @@ CracTools pipelines.
 
 =item NOT_AVAILABLE
 
+=item NUCLEOTIDES => [ A, C, G, T ]
+
 =back
 
 =head1 AUTHORS
