@@ -3,7 +3,7 @@ package CracTools::Utils;
   $CracTools::Utils::DIST = 'CracTools';
 }
 # ABSTRACT: A set of useful functions
-$CracTools::Utils::VERSION = '1.2';
+$CracTools::Utils::VERSION = '1.21';
 use strict;
 use warnings;
 
@@ -184,8 +184,8 @@ sub bamFileIterator {
 
 
 sub getSeqFromIndexedRef {
-  my ($ref_file,$chr,$pos,$length) = @_;
-  my $region = "$chr:$pos-".($pos+$length);
+  my ($ref_file,$chr,$pos,$length,$format) = @_;
+  my $region = "$chr:$pos-".($pos+$length-1);
   return `samtools faidx $ref_file "$region"`;
 }
 
@@ -468,7 +468,7 @@ CracTools::Utils - A set of useful functions
 
 =head1 VERSION
 
-version 1.2
+version 1.21
 
 =head1 SYNOPSIS
 
@@ -484,7 +484,7 @@ version 1.2
   }
 
   # Reading paired-end files easier
-  my $it = pairedEndSeqFileIterator($file);
+  my $it = pairedEndSeqFileIterator($reads1,$reads2,$format);
   while (my $entry = $it->()) {
     print "Read_1 : $entry->{read1}->{seq}
            Read_2 : $entry->{read2}->{seq}";
@@ -597,7 +597,7 @@ reads are sequenced from the same DNA fragment and saved in separated files.
 
 Example:
 
-  my $it = pairedEndSeqFileIterator($file);
+  my $it = pairedEndSeqFileIterator($reads1,$reads2,$format);
   while (my $entry = $it->()) {
     print "Read_1 : $entry->{read1}->{seq}
            Read_2 : $entry->{read2}->{seq}";
@@ -739,6 +739,14 @@ SEE ALSO CracTools::SAMReader::SAMline if you need to parse SAMlines easily
 
 =head2 getSeqFromIndexedRef
 
+BE AWARE this method is only availble if C<samtools> binary is availble.
+
+Return a sequence from a given region in a fasta indexed file
+
+Example:
+
+  my $fasta_seq = CracTools::Utils::getSeqFromIndexedRef("file.fa","chr2",29012,10);
+
 =head1 PARSING LINES
 
 =head2 parseBedLine
